@@ -56,6 +56,7 @@ class OpenApiExecutors(OpenApiLibCore):  # pylint: disable=too-many-instance-att
         invalid_property_default_response: int = 422,
         recursion_limit: int = 1,
         recursion_default: Any = {},
+        faker_locale: Optional[Union[str, List[str]]] = None,
     ) -> None:
         super().__init__(
             source=source,
@@ -69,6 +70,7 @@ class OpenApiExecutors(OpenApiLibCore):  # pylint: disable=too-many-instance-att
             extra_headers=extra_headers,
             recursion_limit=recursion_limit,
             recursion_default=recursion_default,
+            faker_locale=faker_locale,
         )
         self.response_validation = response_validation
         self.disable_server_validation = disable_server_validation
@@ -415,18 +417,13 @@ class OpenApiExecutors(OpenApiLibCore):  # pylint: disable=too-many-instance-att
                     f"response validation of lists of "
                     f"{list_item_schema.get('type')} not supported"
                 )
-            expected_properties = list_item_schema["properties"]
             for resource in json_response:
-                run_keyword(
-                    "validate_resource_properties", resource, expected_properties
-                )
+                run_keyword("validate_resource_properties", resource, list_item_schema)
             # no further validation; value validation of individual resources should
             # be performed on the endpoints for the specific resource
             return None
 
-        run_keyword(
-            "validate_resource_properties", json_response, response_schema["properties"]
-        )
+        run_keyword("validate_resource_properties", json_response, response_schema)
         # ensure the href is valid if present in the response
         if href := json_response.get("href"):
             self._assert_href_is_valid(href, json_response)
@@ -468,21 +465,38 @@ class OpenApiExecutors(OpenApiLibCore):  # pylint: disable=too-many-instance-att
     @staticmethod
     @keyword
     def validate_resource_properties(
-        resource: Dict[str, Any], schema_properties: Dict[str, Any]
+        resource: Dict[str, Any], schema: Dict[str, Any]
     ) -> None:
         """
         Validate that the `resource` does not contain any properties that are not
         defined in the `schema_properties`.
         """
-        if resource.keys() != schema_properties.keys():
-            expected_property_names = sorted(schema_properties.keys())
-            property_names_in_resource = sorted(resource.keys())
-            raise AssertionError(
-                f"Response schema violation: the response contains properties that are "
-                f"not specified in the schema."
-                f"\n\tExpected: {expected_property_names}"
-                f"\n\tGot: {property_names_in_resource}"
+        expected_property_names = set(schema["properties"].keys())
+        property_names_in_resource = set(resource.keys())
+        if expected_property_names != property_names_in_resource:
+            optional_properties = schema.get("required", [])
+            extra_properties = expected_property_names.difference(
+                property_names_in_resource
             )
+            extra_properties = {
+                p for p in extra_properties if p not in optional_properties
+            }
+            missing_properties = property_names_in_resource.difference(
+                expected_property_names
+            )
+            if extra_properties or missing_properties:
+                extra = f"\n\tExtra: {extra_properties}" if extra_properties else ""
+                missing = (
+                    f"\n\tMissing: {missing_properties}" if missing_properties else ""
+                )
+                raise AssertionError(
+                    f"Response schema violation: the response contains properties that are "
+                    f"not specified in the schema or does not contain properties that are ."
+                    f"required according to the schema."
+                    f"\n\tReceived: {property_names_in_resource}"
+                    f"\n\tExpected: {expected_property_names}"
+                    f"{extra}{missing}"
+                )
 
     @staticmethod
     @keyword
