@@ -1,4 +1,3 @@
-# region: docstring
 """
 # OpenApiDriver for Robot Framework®
 
@@ -14,7 +13,7 @@ https://github.com/Snooz82/robotframework-datadriver.
 
 ---
 
-> Note: OpenApiDriver is currently in early development so there are currently
+> Note: OpenApiDriver is still under development so there are currently
 restrictions / limitations that you may encounter when using this library to run
 tests against an API. See [Limitations](#limitations) for details.
 
@@ -71,7 +70,7 @@ document for your API.
 > Note: Although recursion is technically allowed under the OAS, tool support is limited
 and changing the API to not use recursion is recommended.
 At present OpenApiLibCore has limited support for parsing OpenAPI documents with
-recursion in them.
+recursion in them. See the `recursion_limit` and `recursion_default` parameters.
 
 If the openapi document passes this validation, the next step is trying to do a test
 run with a minimal test suite.
@@ -118,19 +117,12 @@ Details about the `mappings_path` variable usage can be found
 
 There are currently a number of limitations to supported API structures, supported
 data types and properties. The following list details the most important ones:
-- Only JSON request and response bodies are currently supported.
+- Only JSON request and response bodies are supported.
 - The unique identifier for a resource as used in the `paths` section of the
     openapi document is expected to be the `id` property on a resource of that type.
-- Limited support for query strings and headers.
-- Limited support for authentication
-    - `username` and `password` can be passed as parameters to use Basic Authentication
-    - A [requests AuthBase instance](https://docs.python-requests.org/en/latest/api/#authentication)
-        can be passed and it will be used as provided.
-    - No support for per-endpoint authorization levels (just simple 401 validation).
-- byte, binary, date, date-time string formats not supported yet.
+- No support for per-endpoint authorization levels (only simple 401 / 403 validation).
 
 """
-# endregion
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
 
@@ -169,8 +161,8 @@ class OpenApiDriver(OpenApiExecutors, DataDriver):
         invalid_property_default_response: int = 422,
         recursion_limit: int = 1,
         recursion_default: Any = {},
+        faker_locale: Optional[Union[str, List[str]]] = None,
     ):
-        # region: docstring
         """
         === source ===
         An absolute path to an openapi.json or openapi.yaml file or an url to such a file.
@@ -254,8 +246,11 @@ class OpenApiDriver(OpenApiExecutors, DataDriver):
         object in JSON. Depending on schema definitions, this may cause schema
         validation errors. If this is the case, `None` (`${NONE}` in Robot Framework)
         can be tried as an alternative.
+
+        === faker_locale ===
+        A locale string or list of locale strings to pass to Faker to be used in
+        generation of string data for supported format types.
         """
-        # endregion
         ignored_endpoints = ignored_endpoints if ignored_endpoints else []
         ignored_responses = ignored_responses if ignored_responses else []
         ignored_testcases = ignored_testcases if ignored_testcases else []
@@ -278,6 +273,7 @@ class OpenApiDriver(OpenApiExecutors, DataDriver):
             invalid_property_default_response=invalid_property_default_response,
             recursion_limit=recursion_limit,
             recursion_default=recursion_default,
+            faker_locale=faker_locale,
         )
 
         endpoints = self.openapi_spec["paths"]
